@@ -101,7 +101,7 @@ class AegisHandler(tornado.web.RequestHandler):
     def prepare(self):
         if self._parent_timer:
             aegis.stdlib.timer_start(self.timer_obj, 'prepare')
-        self.set_header('Cache-Control', 'no-cache, no-store')
+        self.set_header('Cache-Control', 'no-cache, no-store, must-revalidate')
         self.set_header('Pragma', 'no-cache')
         self.set_header('Expires', 'Fri, 21 Dec 2012 03:08:13 GMT')
         self.tmpl['request_name'] = self.page_name = '%s.%s' % (self.__class__.__name__, self.request.method)
@@ -541,9 +541,11 @@ class AegisHandler(tornado.web.RequestHandler):
         is_robot = self.user_is_robot()
         audit_session_id = None
         audit_session_row = None
+        # If session_ck has audit_session_id, also try to fetch it to make sure it exists.
         if self.tmpl.get('session_ck', {}).get('audit_session_id'):
             audit_session_id = self.tmpl['session_ck']['audit_session_id']
             audit_session_row = aegis.model.AuditSession.get_id(audit_session_id)
+        if audit_session_row:
             self.audit_session['last_request_name'] = self.tmpl['request_name']
             self.audit_session['last_request_dttm'] = aegis.database.Literal('NOW()')
             if aegis.database.mysql_available:
@@ -729,13 +731,19 @@ class AegisHandler(tornado.web.RequestHandler):
             marketing_name = 'direct'
             referer = self.request.headers.get('Referer')
             if referer:
-                marketing_name = 'referral'
-                url_parts = urllib.parse.urlparse(referer)
-                organic_netlocs = ['google.com', 'www.google.com', 'www.aol.com', 'aol.com', 'www.ask.com', 'ask.com', 'baidu.com', 'www.bing.com', 'bing.com',
-                                   'www.daum.net', 'daum.net', 'duckduckgo.com', 'ecosia.org', 'search.brave.com', 'www.ecosia.org', 'www.lycos.com', 'www.msn.com',
-                                   'www.yahoo.com', 'm.yahoo.com', 'yahoo.com', 'yandex.ru', 'www.yandex.com']
-                if url_parts.netloc in organic_netlocs:
-                    marketing_name = 'organic'
+                # Leave it as 'direct' if the referer netloc matches domain
+                url_parts = aegis.stdlib.validate_url(referer)
+                if url_parts:
+                    netloc_match = (url_parts.netloc == self.tmpl['domain'])
+                    if not netloc_match:
+                        marketing_name = 'referral'
+                        organic_netlocs = ['google.com', 'www.google.com', 'www.aol.com', 'aol.com', 'www.ask.com', 'ask.com', 'baidu.com', 'www.bing.com', 'bing.com',
+                                           'www.daum.net', 'daum.net', 'duckduckgo.com', 'ecosia.org', 'search.brave.com', 'www.ecosia.org', 'www.lycos.com', 'www.msn.com',
+                                           'www.yahoo.com', 'm.yahoo.com', 'yahoo.com', 'yandex.ru', 'www.yandex.com',
+                                           'com.google.android.googlequicksearchbox',   # android-app://com.google.android.googlequicksearchbox
+                                               ]
+                        if url_parts.netloc in organic_netlocs:
+                            marketing_name = 'organic'
             marketing = aegis.model.Marketing.get_name(marketing_name)
             if marketing:
                 mid = marketing['marketing_id']
